# Numerical ideal Fermi gas

[![Documentation Status](https://readthedocs.org/projects/ifg-py/badge/?version=latest)](https://ifg-py.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/alekseik1/ifg-py.svg?branch=master)](https://travis-ci.org/alekseik1/ifg-py)

## Getting started
```bash
pip install ifg
```

## Functionality
The module can calculate some properties (like pressure, entropy) for ideal Fermi gas model.

See [API reference](https://ifg-py.readthedocs.io/en/latest/) for more information


## Examples
See `examples/` folder for plots and code examples.

## Acknowledgements
- [Library for Fermi integrals](https://pypi.org/project/fdint/)


## Reporting bugs
Use *Issues* to report any errors or bugs.
